==> haskell-parallel-3.2.2.0-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-parallel.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 parallel
version:              3.2.2.0
visibility:           public
id:                   parallel-3.2.2.0-G9JTeCQCHda2yggytvFxi6
key:                  parallel-3.2.2.0-G9JTeCQCHda2yggytvFxi6
license:              BSD-3-Clause
maintainer:           libraries@haskell.org
synopsis:             Parallel programming library
description:
    This package provides a library for parallel programming.

    For documentation start from the "Control.Parallel.Strategies"
    module below.

    For more tutorial documentation, see the book <http://simonmar.github.io/pages/pcph.html Parallel and Concurrent Programming in Haskell>.

    To understand the principles behind the library, see
    <http://simonmar.github.io/bib/papers/strategies.pdf Seq no more: Better Strategies for Parallel Haskell>.

category:             Control, Parallelism
abi:                  b62d31dababe2b680da47806b540aaea
exposed:              True
exposed-modules:
    Control.Parallel Control.Parallel.Strategies Control.Seq

import-dirs:          /usr/lib/ghc-9.0.1/site-local/parallel-3.2.2.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/parallel-3.2.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/parallel-3.2.2.0
hs-libraries:         HSparallel-3.2.2.0-G9JTeCQCHda2yggytvFxi6
depends:
    array-0.5.4.0 base-4.15.0.0 containers-0.6.4.1 deepseq-1.4.5.0
    ghc-prim-0.7.0

haddock-interfaces:   /usr/share/doc/haskell-parallel/html/parallel.haddock
haddock-html:         /usr/share/doc/haskell-parallel/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-parallel-3.2.2.0-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-parallel.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 parallel
version:              3.2.2.0
visibility:           public
id:                   parallel-3.2.2.0-D2aleEa2VnPBr164BdKnms
key:                  parallel-3.2.2.0-D2aleEa2VnPBr164BdKnms
license:              BSD-3-Clause
maintainer:           libraries@haskell.org
synopsis:             Parallel programming library
description:
    This package provides a library for parallel programming.

    For documentation start from the "Control.Parallel.Strategies"
    module below.

    For more tutorial documentation, see the book <http://simonmar.github.io/pages/pcph.html Parallel and Concurrent Programming in Haskell>.

    To understand the principles behind the library, see
    <http://simonmar.github.io/bib/papers/strategies.pdf Seq no more: Better Strategies for Parallel Haskell>.

category:             Control, Parallelism
abi:                  193447847cbfbd4c4e8f4d2c7a8caa39
exposed:              True
exposed-modules:
    Control.Parallel Control.Parallel.Strategies Control.Seq

import-dirs:          /usr/lib/ghc-9.0.2/site-local/parallel-3.2.2.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/parallel-3.2.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/parallel-3.2.2.0
hs-libraries:         HSparallel-3.2.2.0-D2aleEa2VnPBr164BdKnms
depends:
    array-0.5.4.0 base-4.15.1.0 containers-0.6.4.1 deepseq-1.4.5.0
    ghc-prim-0.7.0

haddock-interfaces:   /usr/share/doc/haskell-parallel/html/parallel.haddock
haddock-html:         /usr/share/doc/haskell-parallel/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
